==> ssp-center-api-0.0.8-lqs17-20170511.123945-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteAccountReportMonthService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;


import java.util.List;

import cn.com.duiba.tuia.ssp.center.api.dto.AccountMonthReportDto;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqAccountMonthReportByPage;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqCashDetail;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqMonthBillDto;
import cn.com.duiba.tuia.ssp.center.api.dto.SettledMonthReportRsp;
import cn.com.duiba.wolf.dubbo.DubboResult;

public interface RemoteAccountReportMonthService {

    DubboResult<Integer> selectAmountByPage(ReqAccountMonthReportByPage reqAccountMonthReportByPage);

    DubboResult<List<SettledMonthReportRsp>> selectListByPage(ReqAccountMonthReportByPage reqAccountMonthReportByPage);

    DubboResult<AccountMonthReportDto> selectMonthReportByReportId(Long reportId);

    DubboResult<List<SettledMonthReportRsp>> selectExportList(ReqAccountMonthReportByPage reqAccountMonthReportByPage);

    DubboResult<Boolean> updateMonthReportStatus(Long reportId,Integer settlementStatus);

    /**
     * 查询媒体可提现余额
     * @param mediaId
     * @return
     */
    DubboResult<Long> selectJustlyShareByMediaId(Long mediaId);

    /**
     * 查询媒体所有可提现月账单
     * @param mediaId
     * @return
     */
    DubboResult<List<AccountMonthReportDto>> selectByMediaId (Long mediaId);

    /**
     * 绑定月账单和提现单
     * @param reportId
     * @param cashOrderId
     * @return
     */
    DubboResult<Boolean> updateMonthReportCashOrder(Long reportId,Long cashOrderId);

    /**
     * 通过提现单查询月账单
     * @param cashOrderId
     * @return
     */
    DubboResult<List<AccountMonthReportDto>> selectByCashOrderId ( Long cashOrderId);
    
    /**
     * 
     * 查询媒体用户下面的提现金额
     *
     * @param param
     * @author guyan
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<AccountMonthReportDto>> selectCashAmount(ReqCashDetail param);
    
    /**
     * 
     * 查询用户下所有的月账单数据
     *
     * @param param
     * @author guyan
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<AccountMonthReportDto>> selectAllMonthBillList(ReqMonthBillDto param);
    
    /**
     * 
     * 查询用户下所有的月账单总数
     *
     * @param param
     * @author guyan
     * @return
     * @since JDK 1.6
     */
    DubboResult<Integer> selectAllMonthBillCount(ReqMonthBillDto param);
    
    /**
     * 
     * 查询上个月月账单ID <br/>
     *  
     * @param mediaId
     * @param appId
     * @param lastMonth
     * @author guyan
     * @return
     * @since JDK 1.6
     */
    DubboResult<Long> getLastMonthBillId(Long mediaId,Long appId,String lastMonth);
    
    /**
     * 批量修改月账单
     * 
     * @param monthBillIds
     * @param cashOrderId
     * @author guyan
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> batchUpdateMonthBill(List<Long> monthId, Long cashOrderId);
   

    /**
     * 查询媒体下各个应用的每月的预计分成
     *
     * @param cashOrderId
     * @author guyan
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<AccountMonthReportDto>> selectBillByCashOrder(Long cashOrderId);
    
    /**
     * 查询总的提现金额通过订单ID
     * 
     * @param cashOrderId
     * @return
     * @since JDK 1.6
     */
    DubboResult<Long> selectCashAmountById(Long cashOrderId);
    
    /**
     * 查询已结算月账单
     *
     * @param monthBillId
     * @return
     * @since JDK 1.6
     */
    DubboResult<AccountMonthReportDto> selectSettledMonthBill(Long monthBillId);
    
   
}

==> ssp-center-api-0.1.9-lqs3-20170725.061632-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteAccountReportMonthService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;


import java.util.Date;
import java.util.List;

import cn.com.duiba.tuia.ssp.center.api.dto.AccountMonthReportDto;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqAccountMonthReportByPage;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqMonthBillDto;
import cn.com.duiba.tuia.ssp.center.api.dto.SettledMonthReportRsp;
import cn.com.duiba.tuia.ssp.center.api.dto.SettlementCashOrderDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

public interface RemoteAccountReportMonthService {

    DubboResult<Integer> selectAmountByPage(ReqAccountMonthReportByPage reqAccountMonthReportByPage);

    DubboResult<List<SettledMonthReportRsp>> selectListByPage(ReqAccountMonthReportByPage reqAccountMonthReportByPage);

    DubboResult<AccountMonthReportDto> selectMonthReportByReportId(Long reportId);

    DubboResult<List<SettledMonthReportRsp>> selectExportList(ReqAccountMonthReportByPage reqAccountMonthReportByPage);

    DubboResult<Boolean> updateMonthReportStatus(Long appId, Date curDate,Integer settlementStatus);


    /**
     * 查询媒体所有可提现月账单
     * @param mediaId
     * @return
     */
    DubboResult<List<AccountMonthReportDto>> selectByMediaId (Long mediaId);

    /**
     * 绑定月账单和提现单
     * @param reportId
     * @param cashOrderId
     * @return
     */
    DubboResult<Boolean> updateMonthReportCashOrder(Long reportId,Long cashOrderId);

    /**
     * 通过提现单查询月账单
     * @param cashOrderId
     * @return
     */
    DubboResult<List<AccountMonthReportDto>> selectByCashOrderId ( Long cashOrderId);
    
    /**
     * 
     * 查询用户下所有的月账单数据
     *
     * @param param
     * @author guyan
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<AccountMonthReportDto>> selectAllMonthBillList(ReqMonthBillDto param);
    
    /**
     * 
     * 查询用户下所有的月账单总数
     *
     * @param param
     * @author guyan
     * @return
     * @since JDK 1.6
     */
    DubboResult<Integer> selectAllMonthBillCount(ReqMonthBillDto param);
    
    /**
     * 
     * 查询上个月月账单ID <br/>
     *  
     * @param mediaId
     * @param appId
     * @param lastMonth
     * @author guyan
     * @return
     * @since JDK 1.6
     */
    DubboResult<Long> getLastMonthBillId(Long mediaId,Long appId,String lastMonth);
    
    /**
     * 批量修改月账单
     * 
     * @param monthBillIds
     * @param cashOrderId
     * @author guyan
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> batchUpdateMonthBill(List<Long> appIds,List<String> curDates,Long cashOrderId,Long mediaId);
   

    /**
     * 查询媒体下各个应用的每月的预计分成
     *
     * @param cashOrderId
     * @author guyan
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<AccountMonthReportDto>> selectBillByCashOrder(Long cashOrderId);
    
    /**
     * 查询已结算月账单
     *
     * @param monthBillId
     * @return
     * @since JDK 1.6
     */
    DubboResult<AccountMonthReportDto> selectSettledMonthBill(Long monthBillId);

    /**
     * 通过提现单查询对应的月账单Id
     * @param cashOrderIds
     * @return
     */
    DubboResult<List<Long>> selectIdsByCashOrderIds(List<Long> cashOrderIds);

    /**
     * 通过体现单查询对应的提现金额
     * 如果传入为null或长度为0的集合，则返回空的集合
     */
    DubboResult<List<SettlementCashOrderDto>> selectSettlementByCashOrderIds(List<Long> cashOrderIds);

    /**
     * 按月份和app id查询月账单信息
     */
    DubboResult<AccountMonthReportDto> selectByAppAndDate(Long appId,Date curDate);
}
